==> haskell-network-udp-0.0.0-60-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-network-udp.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 network-udp
version:              0.0.0
visibility:           public
id:                   network-udp-0.0.0-BDB8I6IqcbnBqh2VBotavT
key:                  network-udp-0.0.0-BDB8I6IqcbnBqh2VBotavT
license:              BSD-3-Clause
maintainer:           kazu@iij.ad.jp
author:               Kazu Yamamoto
synopsis:             UDP library
description:          Best current practice library for UDP clients and servers.
category:             Network
abi:                  596ab102b829feee48d2d5e756dcca74
exposed:              True
exposed-modules:      Network.UDP
hidden-modules:       Network.UDP.Recv Network.UDP.Types
import-dirs:          /usr/lib/ghc-9.4.8/site-local/network-udp-0.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/network-udp-0.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/network-udp-0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-network-udp
hs-libraries:         HSnetwork-udp-0.0.0-BDB8I6IqcbnBqh2VBotavT
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    iproute-1.7.15-8gqym1PTsEkCAaYbhB8AF8
    network-3.1.4.0-IeirKeGjruDCEk80u2jHD1

haddock-interfaces:   /usr/share/doc/haskell-network-udp/html/network-udp.haddock
haddock-html:         /usr/share/doc/haskell-network-udp/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-network-udp-0.0.0-61-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-network-udp.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 network-udp
version:              0.0.0
visibility:           public
id:                   network-udp-0.0.0-ELYgVorf852GXco62VjdWT
key:                  network-udp-0.0.0-ELYgVorf852GXco62VjdWT
license:              BSD-3-Clause
maintainer:           kazu@iij.ad.jp
author:               Kazu Yamamoto
synopsis:             UDP library
description:          Best current practice library for UDP clients and servers.
category:             Network
abi:                  5704b431d83db6d6a31dbec74e68d5a7
exposed:              True
exposed-modules:      Network.UDP
hidden-modules:       Network.UDP.Recv Network.UDP.Types
import-dirs:          /usr/lib/ghc-9.4.8/site-local/network-udp-0.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/network-udp-0.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/network-udp-0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-network-udp
hs-libraries:         HSnetwork-udp-0.0.0-ELYgVorf852GXco62VjdWT
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    iproute-1.7.15-4bTvgmu3pwnLw6WjpGAAua
    network-3.1.4.0-2CBRys83VnCFTvPdAqVbyS

haddock-interfaces:   /usr/share/doc/haskell-network-udp/html/network-udp.haddock
haddock-html:         /usr/share/doc/haskell-network-udp/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
